

require "import"
import "android.widget.*"
import "android.view.*"
import "android.content.*"
import "android.os.*"
import "java.text.SimpleDateFormat"
import "java.util.Date"
import "android.speech.tts.TextToSpeech"

local activity = activity
activity.setTitle("Digital Clock")

local layout = LinearLayout(activity)
layout.setOrientation(LinearLayout.VERTICAL)
activity.setContentView(layout)

local railwayTimeTextView = TextView(activity)
railwayTimeTextView.setTextSize(30)
railwayTimeTextView.setTextColor(0xFFff0000) -- Red color for railway time
layout.addView(railwayTimeTextView)

local digitalTimeTextView = TextView(activity)
digitalTimeTextView.setTextSize(30)
layout.addView(digitalTimeTextView)

local dateTextView = TextView(activity)
dateTextView.setTextSize(20)
layout.addView(dateTextView)

local handler = Handler()
local railwayTimeFormat = SimpleDateFormat("HH:mm")
local normalTimeFormat = SimpleDateFormat("hh:mm:ss a")
local dateFormat = SimpleDateFormat("EEEE, MMMM dd yyyy")

local tts = TextToSpeech(activity, nil)

function updateRailwayTime()
    local railwayTime = railwayTimeFormat.format(Date())
    railwayTimeTextView.setText("Railway Time: " .. railwayTime)
    handler.postDelayed(updateRailwayTime, 500) -- Update railway time every half second
end

function updateNormalTime()
    local normalTime = normalTimeFormat.format(Date())
    digitalTimeTextView.setText("Normal Time: " .. normalTime)
    handler.postDelayed(updateNormalTime, 1000) -- Update normal time every second
end

function updateDateTime()
    local currentTime = railwayTimeFormat.format(Date())
    local currentDate = dateFormat.format(Date())
    railwayTimeTextView.setText("Current Time: " .. currentTime)
    digitalTimeTextView.setText("Normal Time: " .. currentTime)
    dateTextView.setText("Current Date: " .. currentDate)
end

updateRailwayTime()
updateNormalTime()
updateDateTime()

local speakTimeButton = Button(activity)
speakTimeButton.setText("Speak Time")
layout.addView(speakTimeButton)

local speakDateButton = Button(activity)
speakDateButton.setText("Speak Date")
layout.addView(speakDateButton)

local speakRailwayTimeButton = Button(activity)
speakRailwayTimeButton.setText("Speak Railway Time")
layout.addView(speakRailwayTimeButton)

speakTimeButton.onClick = function()
    local currentTime = railwayTimeFormat.format(Date())
    tts.speak("The current time is: " .. currentTime, TextToSpeech.QUEUE_FLUSH, nil, "")
end

speakDateButton.onClick = function()
    local currentDate = dateFormat.format(Date())
    tts.speak("Today is: " .. currentDate, TextToSpeech.QUEUE_FLUSH, nil, "")
end

speakRailwayTimeButton.onClick = function()
    local currentTime = railwayTimeFormat.format(Date())
    tts.speak("The current railway time is: " .. currentTime, TextToSpeech.QUEUE_FLUSH, nil, "")
end